
## c8ylp connect

```
Usage: c8ylp connect COMMAND [ARGS]...

  Connect to a device via different protocols (i.e. via ssh)

  A local proxy instance is started automatically (defaults to a random port)
  and the a client of the selected protocol (i.e. ssh) is called to connect to
  it.

  The local proxy instance is shutdown after the client disconnects.

Options:
  -h, --help  Show this message and exit.

Commands:
  ssh  Start once-off proxy and connect via ssh

```
